package Sah::Schemas::Rinci;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-20'; # DATE
our $DIST = 'Sah-Schemas-Rinci'; # DIST
our $VERSION = '1.1.98.0'; # VERSION

1;
# ABSTRACT: Sah schemas for Rinci

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Rinci - Sah schemas for Rinci

=head1 VERSION

This document describes version 1.1.98.0 of Sah::Schemas::Rinci (from Perl distribution Sah-Schemas-Rinci), released on 2021-07-20.

=head1 SAH SCHEMAS

=over

=item * L<rinci::function_meta|Sah::Schema::rinci::function_meta>

Rinci function metadata.

=item * L<rinci::meta|Sah::Schema::rinci::meta>

Rinci metadata.

=item * L<rinci::result_meta|Sah::Schema::rinci::result_meta>

Rinci envelope result metadata.

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Rinci>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Rinci>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Rinci>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020, 2019, 2018, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
