package Sah::SchemaR::rinci::result_meta;

our $DATE = '2021-07-20'; # DATE
our $VERSION = '1.1.98.0'; # VERSION

our $rschema = ["hash",[{_attr=>{"cmdline.*"=>{},"func.*"=>{},"func_content_type.*"=>{}},_prop=>{caption=>{},cmdline=>{},content_type=>{},default_lang=>{},defhash_v=>{},description=>{},func=>{},len=>{},location=>{},logs=>{},name=>{},part_len=>{},part_start=>{},perm_err=>{},prev=>{},results=>{},schema=>{},stream=>{},summary=>{},tags=>{},v=>{},x=>{}},_ver=>1.1,examples=>[{valid=>1,value=>{}},{valid=>1,value=>{stream=>1}}],summary=>"Rinci envelope result metadata"}],["hash"]];

1;
# ABSTRACT: Rinci envelope result metadata

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::rinci::result_meta - Rinci envelope result metadata

=head1 VERSION

This document describes version 1.1.98.0 of Sah::SchemaR::rinci::result_meta (from Perl distribution Sah-Schemas-Rinci), released on 2021-07-20.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Rinci>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Rinci>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Rinci>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020, 2019, 2018, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
